@@ -32,6 +32,6 @@ class TestPaginaArgomento(unittest.TestCase):
                 "plone.leadimage",
                 "collective.dexteritytextindexer",
                 "volto.blocks",
-                "design.plone.contenttypes.behavior.additional_help_infos",
+                "plone.translatable",
             ),
         )
